==> gcat-client-1.0.0-20190318.150208-1-sources.jar: org/gcube/gcat/client/Item.java <==
package org.gcube.gcat.client;

import java.net.MalformedURLException;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;

import javax.ws.rs.WebApplicationException;
import javax.xml.ws.WebServiceException;

import org.gcube.gcat.api.GCatConstants;

/**
 * @author Luca Frosini (ISTI - CNR)
 */
public class Item extends GCatClient implements org.gcube.gcat.api.interfaces.Item<String,Void> {
	
	public Item() throws MalformedURLException {
		super(ITEMS);
	}
	
	public Item(URL enforcedServiceURL) throws MalformedURLException {
		super(enforcedServiceURL, ITEMS);
	}
	
	@Override
	public String list(int limit, int offset) throws WebApplicationException {
		Map<String, String> queryParams = new HashMap<>();
		queryParams.put(GCatConstants.LIMIT_PARAMETER, String.valueOf(limit));
		queryParams.put(GCatConstants.OFFSET_PARAMETER, String.valueOf(offset));
		return super.list(queryParams);
	}
	
	@Override
	public String create(String json) {
		return super.create(json);
	}

	@Override
	public String read(String name) {
		return super.read(name);
	}

	@Override
	public String update(String name, String json) {
		return super.update(json, name);
	}

	@Override
	public Void delete(String name) {
		super.delete(false, name);
		return null;
	}

	@Override
	public Void delete(String name, boolean purge) throws WebServiceException {
		super.delete(purge, name);
		return null;
	}

	@Override
	public Void purge(String name) throws WebServiceException {
		super.delete(true, name);
		return null;
	}
}

==> gcat-client-1.1.0-20190520.132848-4-sources.jar: org/gcube/gcat/client/Item.java <==
package org.gcube.gcat.client;

import java.net.MalformedURLException;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;

import javax.ws.rs.WebApplicationException;
import javax.xml.ws.WebServiceException;

import org.gcube.gcat.api.GCatConstants;

/**
 * @author Luca Frosini (ISTI - CNR)
 */
public class Item extends GCatClient implements org.gcube.gcat.api.interfaces.Item<String,Void> {
	
	public Item() throws MalformedURLException {
		super(ITEMS);
	}
	
	public Item(URL enforcedServiceURL) throws MalformedURLException {
		super(enforcedServiceURL, ITEMS);
	}
	
	@Override
	public String list(int limit, int offset) throws WebApplicationException {
		Map<String, String> queryParams = new HashMap<>();
		queryParams.put(GCatConstants.LIMIT_PARAMETER, String.valueOf(limit));
		queryParams.put(GCatConstants.OFFSET_PARAMETER, String.valueOf(offset));
		return super.list(queryParams);
	}
	
	
	public String create(String json, boolean socialPost) {
		try {
			Map<String,String> queryParams = new HashMap<>();
			queryParams.put(GCatConstants.SOCIAL_POST_PARAMETER, String.valueOf(socialPost));
			return super.create(json, queryParams);
		}catch (WebApplicationException e) {
			throw e;
		}catch (Exception e) {
			throw new WebApplicationException(e);
		}
	}
	
	@Override
	public String create(String json) {
		return super.create(json);
	}

	@Override
	public String read(String name) {
		return super.read(name);
	}

	@Override
	public String update(String name, String json) {
		return super.update(json, name);
	}

	@Override
	public Void delete(String name) {
		super.delete(false, name);
		return null;
	}

	@Override
	public Void delete(String name, boolean purge) throws WebServiceException {
		super.delete(purge, name);
		return null;
	}

	@Override
	public Void purge(String name) throws WebServiceException {
		super.delete(true, name);
		return null;
	}
}
